@@ -5,17 +5,17 @@ use Pcore -class, -res;
 with qw[Pcore::Util::Src::Filter];
 
 sub decompress ($self) {
-    my $json = P->data->from_json( $self->{data} );
+    my $data = P->data->from_json( $self->{data} );
 
-    $self->{data}->$* = P->data->to_json( $json, readable => 1 );
+    $self->{data}->$* = P->data->to_json( $data, readable => 1 );
 
     return res 200;
 }
 
 sub compress ($self) {
-    my $json = P->data->from_json( $self->{data} );
+    my $data = P->data->from_json( $self->{data} );
 
-    $self->{data}->$* = P->data->to_json( $json, readable => 0 );
+    $self->{data}->$* = P->data->to_json( $data, readable => 0 );
 
     return res 200;
 }
